@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Silly::BoneEasy;
-$Bot::Cobalt::Plugin::Silly::BoneEasy::VERSION = '0.031001';
+$Bot::Cobalt::Plugin::Silly::BoneEasy::VERSION = '0.031002';
 use strictures 2;
 
 use Bot::Cobalt::Common;
@@ -64,9 +64,8 @@ Bot::Cobalt::Plugin::Silly::BoneEasy - Get pickup lines from Bone-Easy
 
 A L<Bot::Cobalt> plugin.
 
-Simple bridge to L<Bone::Easy>.
-
-Generates pickup lines that work every time, 60% of the time.
+Calls out to L<Bone::Easy> to generate pickup lines that work every time, 60%
+of the time.
 
 =head1 AUTHOR
 
